@@ -97,30 +97,8 @@ finditer = ReOperator("finditer")
 __all__ = [
     "match", 
     "search", 
+    "split",
     "findall", 
     "finditer", 
 ]
 
-
-if __name__ == "__main__":
-    from sys import stdin
-    print "\n    RUNNING TESTS\n"
-    if "asdasd" |match| r".*(sd).*":
-        print "match[1]",  match[1]
-    if "aXAbXAc" |split| r"XA":
-        print split.result
-        #for item in findall:
-        #    print item
-        print "len",  len(split)
-        print "findall[2]",  split[2]
-
-    print '-----------------------'
-
-    s = StringIO()
-    s.write('a1b2c3\nx4y5z6\n')
-    s.seek(0)
-    for i in s |findall| r'\d': print i
-
-
-
-
